summaryrefslogtreecommitdiffstats
path: root/tests/adhoc/smoke01.sh
diff options
context:
space:
mode:
authorblsaws <bryan.sullivan@att.com>2016-03-14 13:51:31 -0700
committerblsaws <bryan.sullivan@att.com>2016-03-14 13:51:31 -0700
commit8b3949dfb2faa79567e790fcb2d523a3b3e979a6 (patch)
treef9a59596e53e9a4c5b008938a791b1b1d5d3579d /tests/adhoc/smoke01.sh
parent018770bc01c9e8527b937981d5a0e73af283dbc5 (diff)
Change test object names to avoid conflicts.
JIRA: COPPER-4 Change-Id: I206f4bdfc87729461cfd15d304e3214f9ff4cd13 Signed-off-by: blsaws <bryan.sullivan@att.com>
Diffstat (limited to 'tests/adhoc/smoke01.sh')
-rw-r--r--tests/adhoc/smoke01.sh22
1 files changed, 11 insertions, 11 deletions
diff --git a/tests/adhoc/smoke01.sh b/tests/adhoc/smoke01.sh
index 0391fc2..a79fc65 100644
--- a/tests/adhoc/smoke01.sh
+++ b/tests/adhoc/smoke01.sh
@@ -15,7 +15,7 @@
#
# What this is: A basic test to validate an OPNFV install. Creates an image,
# public and private networks, a router, and launches two VMs connected to the
# private network and thru the router, to the internet.
#
# Status: this is a work in progress, under test. Automated ping test to the
@@ -39,26 +39,26 @@ image=$(openstack image list | awk "/ cirros-0.3.3-x86_64 / { print \$2 }")
if [ "$image" == "" ]; then glance --os-image-api-version 1 image-create --name cirros-0.3.3-x86_64 --disk-format qcow2 --location http://download.cirros-cloud.net/0.3.3/cirros-0.3.3-x86_64-disk.img --container-format bare
fi
-neutron net-create public --router:external=true --provider:network_type=flat --provider:physical_network=physnet1
+neutron net-create test_public --router:test_router=true --provider:network_type=flat --provider:physical_network=physnet1
-neutron subnet-create --disable-dhcp public 192.168.10.0/24
+neutron subnet-create --disable-dhcp test_public 192.168.10.0/24
-neutron net-create internal
+neutron net-create test_internal
-neutron subnet-create internal 10.0.0.0/24 --name internal --gateway 10.0.0.1 --enable-dhcp --allocation-pool start=10.0.0.2,end=10.0.0.254 --dns-nameserver 8.8.8.8
+neutron subnet-create test_internal 10.0.0.0/24 --name test_internal --gateway 10.0.0.1 --enable-dhcp --allocation-pool start=10.0.0.2,end=10.0.0.254 --dns-nameserver 8.8.8.8
-neutron router-create external
+neutron router-create test_router
-neutron router-gateway-set external public
+neutron router-gateway-set test_router test_public
-neutron router-interface-add external subnet=internal
+neutron router-interface-add test_router subnet=test_internal
# add a delay since the previous command takes the neutron-api offline for a while (?)
sleep 30
-INTERNAL_NET=$(neutron net-list | awk "/ internal / { print \$2 }")
+test_internal_NET=$(neutron net-list | awk "/ test_internal / { print \$2 }")
-nova boot --flavor m1.tiny --image cirros-0.3.3-x86_64 --nic net-id=$INTERNAL_NET cirros1
+nova boot --flavor m1.tiny --image cirros-0.3.3-x86_64 --nic net-id=$test_internal_NET cirros1
-nova boot --flavor m1.tiny --image cirros-0.3.3-x86_64 --nic net-id=$INTERNAL_NET cirros2
+nova boot --flavor m1.tiny --image cirros-0.3.3-x86_64 --nic net-id=$test_internal_NET cirros2
set +x #echo off
@@ -15,7 +15,7 @@
#
# What this is: A basic test to validate an OPNFV install. Creates an image,
-# public and private networks, a router, and launches two VMs connected to the
+# test_public and private networks, a router, and launches two VMs connected to the
# private network and thru the router, to the internet.
#